@@ -3,6 +3,15 @@ Constants for ocrd.
 """
 from pkg_resources import resource_filename
 
+__all__ = [
+    'TMP_PREFIX',
+    'DEFAULT_UPLOAD_FOLDER',
+    'DOWNLOAD_DIR',
+    'DEFAULT_REPOSITORY_URL',
+    'BASHLIB_FILENAME',
+    'BACKUP_DIR',
+]
+
 TMP_PREFIX = 'ocrd-core-'
 DEFAULT_UPLOAD_FOLDER = '/tmp/uploads-ocrd-core'
 DOWNLOAD_DIR = '/tmp/ocrd-core-downloads'
