@@ -131,7 +131,7 @@ def run_tasks(mets, log_level, page_id, task_strs, overwrite=False):
         log.info("Start processing task '%s'", task)
 
         # execute cli
-        returncode, out, err = run_cli(
+        returncode = run_cli(
             task.executable,
             mets,
             resolver,
@@ -146,7 +146,7 @@ def run_tasks(mets, log_level, page_id, task_strs, overwrite=False):
 
         # check return code
         if returncode != 0:
-            raise Exception("%s exited with non-zero return value %s. STDOUT:\n%s\nSTDERR:\n%s" % (task.executable, returncode, out, err))
+            raise Exception("%s exited with non-zero return value %s." % (task.executable, returncode))
 
         log.info("Finished processing task '%s'", task)
 
